/**
 * @swagger
 * components:
 *   schemas:
 *     Event:
 *       type: object
 *       required:
 *         - eventId
 *         - calendarId
 *         - uuid
 *         - name
 *         - description
 *         - startDateTime
 *         - endDateTime
 *         - createdDate
 *         - location
 *         - createdById
 *         - url
 *         - wholeDay
 *       properties:
 *         eventId:
 *           type: integer
 *           description: The unique identifier for the event
 *           example: 123
 *         calendarId:
 *           type: integer
 *           description: The ID of the calendar this event belongs to
 *           example: 1
 *         uuid:
 *           type: string
 *           description: A unique UUID for the event
 *           example: "550e8400-e29b-41d4-a716-446655440000"
 *         name:
 *           type: string
 *           description: The name/title of the event
 *           example: "Concert at Musikhochschule"
 *         description:
 *           type: string
 *           description: A detailed description of the event
 *           example: "Annual concert at the Musikhochschule"
 *         startDateTime:
 *           type: string
 *           format: date-time
 *           description: The start date and time of the event
 *           example: "2023-06-15T19:00:00.000Z"
 *         endDateTime:
 *           type: string
 *           format: date-time
 *           description: The end date and time of the event
 *           example: "2023-06-15T21:00:00.000Z"
 *         createdDate:
 *           type: string
 *           format: date-time
 *           description: The date and time when the event was created
 *           example: "2023-05-01T10:00:00.000Z"
 *         location:
 *           type: string
 *           description: The location of the event
 *           example: "Musikhochschule, Karlsruhe"
 *         createdBy:
 *           type: string
 *           description: The name of the user who created the event
 *           example: "John Doe"
 *         createdById:
 *           type: integer
 *           description: The ID of the user who created the event
 *           example: 456
 *         url:
 *           type: string
 *           description: A URL with more information about the event
 *           example: "https://www.nachklang.art/events/concert"
 *         wholeDay:
 *           type: boolean
 *           description: Whether the event lasts the whole day
 *           example: false
 *         status:
 *           type: string
 *           description: The status of the event
 *           enum: [PUBLIC, PRIVATE, DRAFT, DELETED]
 *           example: "PUBLIC"
 */
export interface Event {
	eventId: number;
	calendarId: number;
	uuid: string;
	name: string;
	description: string;
	startDateTime: Date;
	endDateTime: Date;
	createdDate: Date;
	location: string;
	createdBy?: string;
	createdById: number;
	url: string;
	wholeDay: boolean;
	status?: string;
}
