/**
 * @swagger
 * components:
 *   schemas:
 *     Session:
 *       type: object
 *       required:
 *         - sessionId
 *         - userId
 *         - sessionKey
 *         - sessionKeyHash
 *         - lastIP
 *       properties:
 *         sessionId:
 *           type: integer
 *           description: The unique identifier for the session
 *           example: 789
 *         userId:
 *           type: integer
 *           description: The ID of the user this session belongs to
 *           example: 456
 *         sessionKey:
 *           type: string
 *           description: The session key used for authentication
 *           example: "abc123def456"
 *         sessionKeyHash:
 *           type: string
 *           description: The hashed session key (not returned in API responses)
 *           example: "$2a$10$dXJ3SW6G7P50lGmMkkmwe.20cQQubK3.HZWzG3YB1tlRy.fqvM/BG"
 *         createdDate:
 *           type: string
 *           format: date-time
 *           description: The date and time when the session was created
 *           example: "2023-05-01T10:00:00.000Z"
 *         validUntil:
 *           type: string
 *           format: date-time
 *           description: The date and time until when the session is valid
 *           example: "2023-05-08T10:00:00.000Z"
 *         lastIP:
 *           type: string
 *           description: The last IP address used with this session
 *           example: "192.168.1.1"
 */
export interface Session {
	sessionId: number;
	userId: number;
	sessionKey: string;
	sessionKeyHash: string;
	createdDate?: Date;
	validUntil?: Date;
	lastIP: string;
}
